@@ -1,11 +1,12 @@
 .lec.init <- function () {
   if(exists(".lec.Random.seed.table", envir=.GlobalEnv))
     rm(".lec.Random.seed.table", envir=.GlobalEnv)
+  pos <- 1
   assign(".lec.Random.seed.table",list(Cg=matrix(0,nrow=0,ncol=6),
                                        Bg=matrix(0,nrow=0,ncol=6),
                                        Ig=matrix(0,nrow=0,ncol=6),
                                        AIP=matrix(0,nrow=0,ncol=2),
-                                       name=c()), envir=.GlobalEnv)
+                                       name=c()), envir=as.environment(pos))
   .Call("r_create_current_stream",PACKAGE="rlecuyer")
   return(1)
 }
@@ -201,12 +202,14 @@
         .lec.Random.seed.table$Ig<<-.lec.Random.seed.table$Ig[-which,]
         .lec.Random.seed.table$AIP<<-.lec.Random.seed.table$AIP[-which,]
         .lec.Random.seed.table$name <<- .lec.Random.seed.table$name[-which]
-      } else  # table empty
-      assign(".lec.Random.seed.table",list(Cg=matrix(0,nrow=0,ncol=6),
+      } else  {# table empty
+      	pos <- 1
+      	assign(".lec.Random.seed.table",list(Cg=matrix(0,nrow=0,ncol=6),
                                            Bg=matrix(0,nrow=0,ncol=6),
                                            Ig=matrix(0,nrow=0,ncol=6),
                                            AIP=matrix(0,nrow=0,ncol=2),
-                                           name=c()), envir=.GlobalEnv)
+                                           name=c()), envir=as.environment(pos))
+      }
     }
   }
 }
